@@ -23,13 +23,11 @@
  * it controls the window behaviour.
  */
 
-#include <libgd/gd.h>
-
+#include "bjb-application.h"
 #include "bjb-controller.h"
 #include "bjb-main-view.h"
 #include "bjb-window-base.h"
 
-
 /*
  * The start-up number of items to show,
  * and its incrementation
@@ -50,12 +48,15 @@ struct _BjbController
   GtkTreeModel   *model;
 
   BjbWindowBase  *window;
+  BjbSettings    *settings;
 
   GList          *items_to_show;
   gint            n_items_to_show;
   gboolean        remaining_items;
   GMutex          mutex;
 
+  gboolean        selection_mode;
+
   gboolean        connected;
   gulong          manager_change;
 };
@@ -91,15 +92,13 @@ bjb_controller_init (BjbController *self)
   GtkListStore *store;
 
   /* Create the columns */
-  store = gtk_list_store_new (GD_MAIN_COLUMN_LAST,
-                              G_TYPE_STRING,      // urn
-                              G_TYPE_STRING,      // uri
-                              G_TYPE_STRING,      // name
-                              G_TYPE_STRING,      // author
-                              CAIRO_GOBJECT_TYPE_SURFACE, // icon then note
-                              G_TYPE_INT64,       // mtime
-                              G_TYPE_BOOLEAN,     // state
-                              G_TYPE_UINT);       // pulse
+  store = gtk_list_store_new (BJB_MODEL_COLUMN_LAST,
+                              G_TYPE_STRING,   // BJB_MODEL_COLUMN_UUID
+                              G_TYPE_STRING,   // BJB_MODEL_COLUMN_TITLE
+                              G_TYPE_STRING,   // BJB_MODEL_COLUMN_TEXT
+                              G_TYPE_INT64,    // BJB_MODEL_COLUMN_MTIME
+                              G_TYPE_STRING,   // BJB_MODEL_COLUMN_COLOR
+                              G_TYPE_BOOLEAN); // BJB_MODEL_COLUMN_SELECTED
 
   self->model = GTK_TREE_MODEL (store);
   self->n_items_to_show = BJB_ITEMS_SLICE;
@@ -203,7 +202,7 @@ bjb_controller_get_iter (BjbController *self,
   while (try)
   {
     gchar *item_path;
-    gtk_tree_model_get (self->model, *iter, GD_MAIN_COLUMN_URI, &item_path, -1);
+    gtk_tree_model_get (self->model, *iter, BJB_MODEL_COLUMN_UUID, &item_path, -1);
 
     /* If we look for the item, check by uid */
     if (needle && g_strcmp0 (item_path, needle) == 0)
@@ -234,12 +233,11 @@ bjb_controller_add_item (BjbController *self,
                          gboolean       prepend,
                          GtkTreeIter   *sibling)
 {
-  GtkTreeIter    iter;
-  GtkListStore  *store;
-  cairo_surface_t *surface = NULL;
-  const gchar   *uuid;
-  BjbWindowBase  *win;
-  gint scale;
+  GtkTreeIter      iter;
+  GtkListStore    *store;
+  GdkRGBA          note_color;
+  const char      *text       = _("Notebook");
+  g_autofree char *color      = NULL;
 
   g_return_if_fail (BIJI_IS_ITEM (item));
   store = GTK_LIST_STORE (self->model);
@@ -259,34 +257,24 @@ bjb_controller_add_item (BjbController *self,
   else
     gtk_list_store_append (store, &iter);
 
+  if (BIJI_IS_NOTE_OBJ (item))
+    {
+      text = biji_note_obj_get_raw_text (BIJI_NOTE_OBJ (item));
+      if (biji_note_obj_get_rgba (BIJI_NOTE_OBJ (item), &note_color))
+        color = gdk_rgba_to_string (&note_color);
+    }
 
-  /* First , if there is a gd main view , and if gd main view
-   * is a list, then load the smaller emblem */
-  win = self->window;
-  scale = gtk_widget_get_scale_factor (GTK_WIDGET (win));
-
-  if (bjb_window_base_get_main_view (win)
-      && bjb_main_view_get_view_type
-                (bjb_window_base_get_main_view (win)) == GD_MAIN_VIEW_LIST)
-    surface = biji_item_get_emblem (item, scale);
-
-  /* Else, load the icon */
-  if (!surface)
-    surface = biji_item_get_icon (item, scale);
-
-  /* Appart from pixbuf, both icon & list view types
-   * currently use the same model */
-  uuid = biji_item_get_uuid (item);
-
-  gtk_list_store_set (store, &iter,
-       GD_MAIN_COLUMN_ID, uuid,
-       GD_MAIN_COLUMN_URI, uuid,
-       GD_MAIN_COLUMN_PRIMARY_TEXT, biji_item_get_title (item),
-       GD_MAIN_COLUMN_SECONDARY_TEXT, NULL,
-       GD_MAIN_COLUMN_ICON, surface,
-       GD_MAIN_COLUMN_MTIME, biji_item_get_mtime (item),
-       -1);
+  if (!color)
+    color = g_strdup (bjb_settings_get_default_color (self->settings));
 
+  gtk_list_store_set (store,
+                      &iter,
+                      BJB_MODEL_COLUMN_UUID,  biji_item_get_uuid (item),
+                      BJB_MODEL_COLUMN_TITLE, biji_item_get_title (item),
+                      BJB_MODEL_COLUMN_TEXT,  text,
+                      BJB_MODEL_COLUMN_MTIME, biji_item_get_mtime (item),
+                      BJB_MODEL_COLUMN_COLOR, color,
+                      -1);
 }
 
 /* If the user searches for notes, is the note searched? */
@@ -477,7 +465,7 @@ update_controller_callback (GList *result,
   self = BJB_CONTROLLER (user_data);
   self->remaining_items = FALSE;
 
-  if (!result && self->group == BIJI_LIVING_ITEMS)
+  if (!result)
   {
     bjb_window_base_switch_to (self->window, BJB_WINDOW_BASE_NO_RESULT);
     return;
@@ -520,8 +508,6 @@ update_controller_callback (GList *result,
   }
 }
 
-
-
 void
 bjb_controller_apply_needle (BjbController *self)
 {
@@ -537,9 +523,13 @@ bjb_controller_apply_needle (BjbController *self)
   {
     result = biji_manager_get_items (self->manager, self->group);
 
-    if (result == NULL && self->group == BIJI_LIVING_ITEMS)
-      bjb_window_base_switch_to (self->window, BJB_WINDOW_BASE_NO_NOTE);
-
+    if (result == NULL)
+      {
+        if (!self->notebook && self->group == BIJI_LIVING_ITEMS)
+          bjb_window_base_switch_to (self->window, BJB_WINDOW_BASE_NO_NOTE);
+        else
+          bjb_window_base_switch_to (self->window, BJB_WINDOW_BASE_NO_RESULT);
+      }
     else
       update_controller_callback (result, self);
 
@@ -637,9 +627,13 @@ on_manager_changed (BijiManager            *manager,
         gtk_list_store_remove (GTK_LIST_STORE (self->model), p_iter);
 
       self->items_to_show = g_list_remove (self->items_to_show, item);
-      if (self->items_to_show == NULL && group == BIJI_LIVING_ITEMS)
-        bjb_window_base_switch_to (self->window, BJB_WINDOW_BASE_NO_NOTE);
-
+      if (self->items_to_show == NULL)
+        {
+          if (!self->notebook && group == BIJI_LIVING_ITEMS)
+            bjb_window_base_switch_to (self->window, BJB_WINDOW_BASE_NO_NOTE);
+          else
+            bjb_window_base_switch_to (self->window, BJB_WINDOW_BASE_NO_RESULT);
+        }
       else
         notify_displayed_items_changed (self);
 
@@ -682,9 +676,12 @@ bjb_controller_disconnect (BjbController *self)
 static void
 bjb_controller_constructed (GObject *obj)
 {
+  BjbController *self = BJB_CONTROLLER (obj);
   G_OBJECT_CLASS(bjb_controller_parent_class)->constructed(obj);
 
-  bjb_controller_connect (BJB_CONTROLLER (obj));
+  self->settings = bjb_app_get_settings (g_application_get_default ());
+
+  bjb_controller_connect (self);
 }
 
 static void
@@ -869,7 +866,7 @@ bjb_controller_set_group (BjbController   *self,
 
     else
       bjb_controller_apply_needle (self);
-    //bjb_window_base_switch_to (self->window, group);
+
     return;
   }
   else /* Archives */
@@ -901,3 +898,130 @@ bjb_controller_get_remaining_items (BjbController *self)
 {
   return self->remaining_items;
 }
+
+static gboolean
+bjb_controller_build_selection_list_foreach (GtkTreeModel *model,
+                                             GtkTreePath  *path,
+                                             GtkTreeIter  *iter,
+                                             gpointer      user_data)
+{
+  GList    **sel;
+  gboolean   is_selected;
+
+  sel = user_data;
+
+  gtk_tree_model_get (model,
+                      iter,
+                      BJB_MODEL_COLUMN_SELECTED, &is_selected,
+                      -1);
+
+  if (is_selected)
+    {
+      *sel = g_list_prepend (*sel, gtk_tree_path_copy (path));
+    }
+
+  return FALSE;
+}
+
+GList *
+bjb_controller_get_selection (BjbController *self)
+{
+  GList *retval = NULL;
+
+  gtk_tree_model_foreach (self->model,
+                          bjb_controller_build_selection_list_foreach,
+                          &retval);
+
+  return g_list_reverse (retval);
+}
+
+static void
+bjb_controller_set_selection (GtkListStore *store,
+                              GtkTreeIter  *iter,
+                              gboolean      selection)
+{
+  gtk_list_store_set (store, iter,
+                      BJB_MODEL_COLUMN_SELECTED, selection,
+                      -1);
+}
+
+static gboolean
+bjb_controller_set_selection_foreach (GtkTreeModel *model,
+                                      GtkTreePath  *path,
+                                      GtkTreeIter  *iter,
+                                      gpointer      user_data)
+{
+  gboolean selection = GPOINTER_TO_INT (user_data);
+
+  bjb_controller_set_selection (GTK_LIST_STORE (model), iter, selection);
+
+  return FALSE;
+}
+
+static void
+bjb_controller_set_all_selection (BjbController *self,
+                                  gboolean       selection)
+{
+  gtk_tree_model_foreach (self->model,
+                          bjb_controller_set_selection_foreach,
+                          GINT_TO_POINTER (selection));
+
+  notify_displayed_items_changed (self);
+}
+
+void
+bjb_controller_select_item (BjbController *self,
+                            const char    *iter_string)
+{
+  GtkTreeIter iter;
+  if (!gtk_tree_model_get_iter_from_string (self->model, &iter, iter_string))
+    return;
+  bjb_controller_set_selection (GTK_LIST_STORE (self->model), &iter, TRUE);
+}
+
+void
+bjb_controller_unselect_item (BjbController *self,
+                              const char    *iter_string)
+{
+  GtkTreeIter iter;
+  if (!gtk_tree_model_get_iter_from_string (self->model, &iter, iter_string))
+    return;
+  bjb_controller_set_selection (GTK_LIST_STORE (self->model), &iter, FALSE);
+}
+
+void
+bjb_controller_select_all (BjbController *self)
+{
+  bjb_controller_set_all_selection (self, TRUE);
+}
+
+void
+bjb_controller_unselect_all (BjbController *self)
+{
+  bjb_controller_set_all_selection (self, FALSE);
+}
+
+gboolean
+bjb_controller_get_selection_mode (BjbController *self)
+{
+  return self->selection_mode;
+}
+
+void
+bjb_controller_set_selection_mode (BjbController *self,
+                                   gboolean       selection_mode)
+{
+  if (self->selection_mode != selection_mode)
+    {
+      self->selection_mode = selection_mode;
+      bjb_controller_unselect_all (self);
+    }
+}
+
+gboolean
+bjb_controller_is_all_selected (BjbController *self)
+{
+  g_autoptr (GList) selection_list = bjb_controller_get_selection (self);
+  return g_list_length (selection_list) == g_list_length (self->items_to_show);
+}
+
