@@ -19,7 +19,6 @@
 #include "config.h"
 
 #include <glib/gi18n.h>
-#include <libgd/gd.h>
 
 #include "bjb-application.h"
 #include "bjb-color-button.h"
@@ -32,11 +31,9 @@
 typedef enum
 {
   BJB_TOOLBAR_0,
-  BJB_TOOLBAR_STD_LIST,
-  BJB_TOOLBAR_STD_ICON,
+  BJB_TOOLBAR_LIST,
   BJB_TOOLBAR_SELECT,
   BJB_TOOLBAR_TRASH_LIST,
-  BJB_TOOLBAR_TRASH_ICON,
   BJB_TOOLBAR_TRASH_SELECT,
   BJB_TOOLBAR_NOTE_VIEW
 } BjbToolbarType;
@@ -58,12 +55,9 @@ struct _BjbMainToolbar
   GtkWidget *new_button;
   GtkWidget *back_button;
   GtkWidget *title_entry;
-  GtkWidget *list_button;
-  GtkWidget *grid_button;
   GtkWidget *select_button;
   GtkWidget *cancel_button;
   GtkWidget *search_button;
-  GtkWidget *style_buttons;
   GtkWidget *empty_button;
   GtkWidget *color_button;
   GtkWidget *button_stack;
@@ -72,9 +66,6 @@ struct _BjbMainToolbar
 
   /* Menu items */
   GtkWidget *new_window_item;
-  GtkWidget *undo_item;
-  GtkWidget *redo_item;
-  GtkWidget *trash_item;
   GtkWidget *last_update_item;
 
   /* Signals */
@@ -88,6 +79,9 @@ struct _BjbMainToolbar
   gulong note_color_changed;
   gulong last_updated;
   GtkAccelGroup *accel;
+
+  /* When notebook view */
+  BijiNotebook *notebook;
 };
 
 /* GObject properties */
@@ -176,49 +170,11 @@ static void
 on_selection_mode_clicked (BjbMainToolbar *self,
                            GtkWidget      *button)
 {
-  g_assert (BJB_IS_MAIN_TOOLBAR (self));
-  g_assert (GTK_IS_BUTTON (button));
-
   if (button == self->cancel_button)
-  {
     bjb_main_view_set_selection_mode (self->parent, FALSE);
-  }
-
-  /* Force refresh. We go to selection mode but nothing yet selected
-   * Thus no signal emited */
   else
-  {
     bjb_main_view_set_selection_mode (self->parent, TRUE);
-    on_view_selection_changed_cb (self);
-  }
-}
-
-static gboolean
-on_view_mode_clicked (BjbMainToolbar *self,
-                      GtkWidget      *button)
-{
-  GdMainViewType current;
-
-  g_assert (BJB_IS_MAIN_TOOLBAR (self));
-  g_assert (GTK_IS_BUTTON (button));
-
-  current = bjb_main_view_get_view_type (self->parent);
-
-  switch ( current )
-  {
-    case GD_MAIN_VIEW_ICON :
-      bjb_main_view_set_view_type (self->parent, GD_MAIN_VIEW_LIST);
-      break ;
-    case GD_MAIN_VIEW_LIST :
-      bjb_main_view_set_view_type (self->parent, GD_MAIN_VIEW_ICON);
-      break ;
-    default:
-      bjb_main_view_set_view_type (self->parent, GD_MAIN_VIEW_ICON);
-  }
-
-  bjb_main_view_update_model (self->parent);
-  gtk_widget_hide (button);
-  return TRUE;
+  on_view_selection_changed_cb (self);
 }
 
 static void
@@ -227,11 +183,11 @@ update_selection_buttons (BjbController *controller,
                           gboolean remaining,
                           BjbMainToolbar *self)
 {
-  gtk_widget_set_sensitive (self->grid_button, some_item_is_visible);
-  gtk_widget_set_sensitive (self->list_button, some_item_is_visible);
   gtk_widget_set_sensitive (self->empty_button, some_item_is_visible);
   gtk_widget_set_sensitive (self->search_button, some_item_is_visible);
   gtk_widget_set_sensitive (self->select_button, some_item_is_visible);
+
+  on_view_selection_changed_cb (self);
 }
 
 static void
@@ -251,7 +207,6 @@ populate_bar_for_selection (BjbMainToolbar *self)
   gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (self), FALSE);
   gtk_widget_hide (self->select_button);
   gtk_widget_hide (self->button_stack);
-  gtk_widget_hide (self->style_buttons);
   gtk_widget_hide (self->main_button);
   gtk_widget_show (self->cancel_button);
 
@@ -451,9 +406,10 @@ on_title_changed (BjbMainToolbar *self,
 static void
 populate_bar_for_note_view (BjbMainToolbar *self)
 {
-  BjbSettings *settings;
-  GdkRGBA      color;
-  gboolean     detached;
+  BjbSettings     *settings;
+  GdkRGBA          color;
+  gboolean         detached;
+  g_autofree char *label = NULL;
 
   self->note = bjb_window_base_get_note (BJB_WINDOW_BASE (self->window));
   detached = bjb_window_base_is_detached (BJB_WINDOW_BASE (self->window));
@@ -461,17 +417,24 @@ populate_bar_for_note_view (BjbMainToolbar *self)
   if (!self->note) /* no reason this would happen */
     return;
 
+  gtk_widget_hide (self->new_button);
+  gtk_widget_hide (self->search_button);
+  gtk_widget_hide (self->select_button);
+  gtk_widget_hide (self->main_button);
+  gtk_widget_show (self->back_button);
+
+  if (biji_note_obj_is_trashed (self->note))
+    {
+      label = g_strdup_printf ("%s", biji_item_get_title (BIJI_ITEM (self->note)));
+      gtk_header_bar_set_title (GTK_HEADER_BAR (self), label);
+      gtk_header_bar_set_subtitle (GTK_HEADER_BAR (self), NULL);
+      return;
+    }
+
   settings = bjb_app_get_settings (g_application_get_default());
 
   gtk_header_bar_set_custom_title (GTK_HEADER_BAR (self), self->title_entry);
 
-  gtk_widget_hide (self->new_button);
-  gtk_widget_hide (self->style_buttons);
-  gtk_widget_hide (self->search_button);
-  gtk_widget_hide (self->select_button);
-  gtk_widget_hide (self->main_button);
-
-  gtk_widget_show (self->back_button);
   gtk_widget_show (self->menu_button);
 
   if (detached)
@@ -503,11 +466,6 @@ populate_bar_for_note_view (BjbMainToolbar *self)
                                G_CALLBACK (on_note_color_changed), self->color_button);
   }
 
-  if (biji_note_obj_is_trashed (self->note))
-    gtk_widget_hide (self->trash_item);
-  else
-    gtk_widget_show (self->trash_item);
-
   /* Note Last Updated */
   on_last_updated_cb (BIJI_ITEM (self->note), self);
   self->last_updated = g_signal_connect (self->note,"changed",
@@ -522,7 +480,6 @@ bjb_main_toolbar_reset (BjbMainToolbar *self)
   gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (self), TRUE);
 
   gtk_widget_show (self->button_stack);
-  gtk_widget_show (self->style_buttons);
   gtk_widget_show (self->select_button);
   gtk_widget_show (self->search_button);
   gtk_widget_show (self->new_button);
@@ -548,31 +505,18 @@ populate_bar_switch (BjbMainToolbar *self)
       populate_bar_for_selection (self);
       break;
 
-    case BJB_TOOLBAR_STD_ICON:
+    case BJB_TOOLBAR_LIST:
       populate_bar_for_standard(self);
-      gtk_widget_show (self->list_button);
       update_selection_buttons (self->controller,
                                 bjb_controller_shows_item (self->controller),
                                 TRUE,
                                 self);
       break;
 
-    case BJB_TOOLBAR_STD_LIST:
-      populate_bar_for_standard(self);
-      gtk_widget_show (self->grid_button);
-      update_selection_buttons (self->controller,
-                                bjb_controller_shows_item (self->controller),
-                                TRUE,
-                                self);
-      break;
-
-
-    case BJB_TOOLBAR_TRASH_ICON:
     case BJB_TOOLBAR_TRASH_LIST:
       populate_bar_for_trash (self);
       break;
 
-
     case BJB_TOOLBAR_NOTE_VIEW:
       populate_bar_for_note_view (self);
       break;
@@ -589,67 +533,44 @@ populate_main_toolbar(BjbMainToolbar *self)
 {
   BjbToolbarType to_be = BJB_TOOLBAR_0 ;
   BjbWindowViewType view_type;
+  BijiItemsGroup group;
+  gboolean selection_mode;
+  BijiNotebook *new_notebook;
 
   view_type = bjb_window_base_get_view_type (BJB_WINDOW_BASE (self->window));
+  group = bjb_controller_get_group (self->controller);
+  new_notebook = bjb_controller_get_notebook (self->controller);
+  selection_mode = bjb_main_view_get_selection_mode (self->parent);
 
-  switch (view_type)
-  {
-    case BJB_WINDOW_BASE_NOTE_VIEW:
-      to_be = BJB_TOOLBAR_NOTE_VIEW;
-      break;
+  /* Note view */
+  if (view_type == BJB_WINDOW_BASE_NOTE_VIEW)
+    to_be = BJB_TOOLBAR_NOTE_VIEW;
 
-    case BJB_WINDOW_BASE_NO_NOTE:
-    case BJB_WINDOW_BASE_NO_RESULT:
-    case BJB_WINDOW_BASE_MAIN_VIEW:
+  /* Main view in selection mode */
+  else if (group == BIJI_LIVING_ITEMS && selection_mode)
+    to_be = BJB_TOOLBAR_SELECT;
 
-      if (bjb_main_view_get_selection_mode (self->parent) == TRUE)
-        to_be = BJB_TOOLBAR_SELECT;
+  /* Trash view in selection mode */
+  else if (group == BIJI_ARCHIVED_ITEMS && selection_mode)
+    to_be = BJB_TOOLBAR_TRASH_SELECT;
 
-      else if (bjb_main_view_get_view_type (self->parent) == GD_MAIN_VIEW_ICON)
-        to_be = BJB_TOOLBAR_STD_ICON;
-
-      else if (bjb_main_view_get_view_type (self->parent) == GD_MAIN_VIEW_LIST)
-        to_be = BJB_TOOLBAR_STD_LIST;
-
-      break;
-
-
-    case BJB_WINDOW_BASE_ARCHIVE_VIEW:
-
-      if (bjb_main_view_get_selection_mode (self->parent) == TRUE)
-        to_be = BJB_TOOLBAR_TRASH_SELECT;
-
-      else if (bjb_main_view_get_view_type (self->parent) == GD_MAIN_VIEW_ICON)
-        to_be = BJB_TOOLBAR_TRASH_ICON;
-
-      else if (bjb_main_view_get_view_type (self->parent) == GD_MAIN_VIEW_LIST)
-        to_be = BJB_TOOLBAR_TRASH_LIST;
-
-
-      break;
-
-
-
-    /* Not really a toolbar,
-     * still used for Spinner */
-    case BJB_WINDOW_BASE_SPINNER_VIEW:
-    case BJB_WINDOW_BASE_ERROR_TRACKER:
-    case BJB_WINDOW_BASE_NO_VIEW:
-    default:
-      break;
-  }
+  /* Trash view */
+  else if (group == BIJI_ARCHIVED_ITEMS && !selection_mode)
+    to_be = BJB_TOOLBAR_TRASH_LIST;
 
+  /* Main view and everything else */
+  else
+    to_be = BJB_TOOLBAR_LIST;
 
   /* Simply clear then populate */
-  if (to_be != self->type || view_type == BJB_WINDOW_BASE_ARCHIVE_VIEW)
+  if (to_be != self->type || self->notebook != new_notebook)
   {
     /* If we leave a note view */
     if (self->type == BJB_TOOLBAR_NOTE_VIEW)
       disconnect_note_handlers (self);
 
     self->type = to_be;
-    /* bjb_main_toolbar_clear (self); */
-
+    self->notebook = new_notebook;
 
     if (self->search_handler != 0)
     {
@@ -794,11 +715,8 @@ bjb_main_toolbar_class_init (BjbMainToolbarClass *klass)
   gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, new_button);
   gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, back_button);
   gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, title_entry);
-  gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, list_button);
-  gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, grid_button);
   gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, search_button);
   gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, empty_button);
-  gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, style_buttons);
   gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, cancel_button);
   gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, select_button);
   gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, color_button);
@@ -807,15 +725,11 @@ bjb_main_toolbar_class_init (BjbMainToolbarClass *klass)
 
   /* Menu items */
   gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, new_window_item);
-  gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, undo_item);
-  gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, redo_item);
-  gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, trash_item);
   gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, last_update_item);
 
   gtk_widget_class_bind_template_callback (widget_class, on_new_note_clicked);
   gtk_widget_class_bind_template_callback (widget_class, on_selection_mode_clicked);
   gtk_widget_class_bind_template_callback (widget_class, on_back_button_clicked);
-  gtk_widget_class_bind_template_callback (widget_class, on_view_mode_clicked);
   gtk_widget_class_bind_template_callback (widget_class, on_empty_clicked_callback);
   gtk_widget_class_bind_template_callback (widget_class, on_color_button_clicked);
 
