@@ -4,7 +4,6 @@
 #include <stdlib.h>
 
 #include <libbiji/libbiji.h>
-#include <libgd/gd.h>
 
 #include "bjb-application.h"
 #include "bjb-empty-results-box.h"
@@ -220,6 +219,19 @@ on_detach_window_cb (GSimpleAction *action,
   bijiben_new_window_for_note (g_application_get_default (), note);
 }
 
+static void
+on_paste_cb (GSimpleAction *action,
+             GVariant      *parameter,
+             gpointer       user_data)
+{
+  BijiNoteObj *note = bjb_window_base_get_note (BJB_WINDOW_BASE (user_data));
+
+  if (!note)
+    return;
+
+  biji_webkit_editor_paste (BIJI_WEBKIT_EDITOR (biji_note_obj_get_editor (note)));
+}
+
 static void
 on_undo_cb (GSimpleAction *action,
             GVariant      *parameter,
@@ -327,7 +339,6 @@ bjb_window_base_load_geometry (BjbWindowBase *self)
 static void
 bjb_window_base_destroy (gpointer a, BjbWindowBase * self)
 {
-  bjb_main_view_disconnect_scrolled_window (self->view);
   bjb_controller_disconnect (self->controller);
   bjb_window_base_save_geometry (self);
 }
@@ -353,6 +364,7 @@ bjb_window_base_configure_event (GtkWidget         *widget,
 
 static GActionEntry win_entries[] = {
   { "detach-window", on_detach_window_cb, NULL, NULL, NULL },
+  { "paste", on_paste_cb, NULL, NULL, NULL },
   { "undo", on_undo_cb, NULL, NULL, NULL },
   { "redo", on_redo_cb, NULL, NULL, NULL },
   { "view-notebooks", on_view_notebooks_cb, NULL, NULL, NULL },
@@ -571,14 +583,12 @@ bjb_window_base_switch_to (BjbWindowBase *self, BjbWindowViewType type)
 
     case BJB_WINDOW_BASE_MAIN_VIEW:
       bjb_search_toolbar_connect (self->search_bar);
-      bjb_main_view_connect_signals (self->view);
       gtk_widget_show (GTK_WIDGET (self->search_bar));
       gtk_stack_set_visible_child_name (self->stack, "main-view");
       break;
 
    case BJB_WINDOW_BASE_ARCHIVE_VIEW:
       bjb_search_toolbar_connect (self->search_bar);
-      bjb_main_view_connect_signals (self->view);
       gtk_widget_show (GTK_WIDGET (self->search_bar));
       gtk_stack_set_visible_child_name (self->stack, "main-view");
       break;
